@@ -1,10 +1,12 @@
 from __future__ import print_function
 
 __all__ = [
+    "AWTEvent",
     "Color",
     "Component",
     "Container",
     "Frame",
+    "Graphics",
     "Image",
     "Toolkit",
     "Window",
@@ -12,12 +14,34 @@ __all__ = [
 
 from typing import Any, Optional
 
-from java.lang import Object
+from java.lang import Object, String
+from java.util import EventObject
+
+
+class AWTEvent(EventObject):
+    _id = None  # type: int
+
+    def __init__(self, source, id):
+        # type: (Object, int) -> None
+        super(AWTEvent, self).__init__(source)
+        self._id = id
+
+    def getID(self):
+        # type: () -> int
+        return self._id
+
+    def paramString(self):
+        # type: () -> String
+        pass
+
+    def setSource(self, newSource):
+        # type: (Object) -> None
+        pass
 
 
 class Color(Object):
     def __init__(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         print(args)
 
 
@@ -37,7 +61,7 @@ class Component(Object):
 
 class Container(Component):
     def add(self, *args):
-        # type: (Any) -> Optional[Component]
+        # type: (*Any) -> Optional[Component]
         pass
 
 
@@ -72,11 +96,17 @@ class Toolkit(Object):
 
 class Window(Container):
     def __init__(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         pass
 
 
 class Frame(Window):
     def __init__(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         super(Frame, self).__init__(*args)
+
+
+class Graphics(Object):
+    def create(self):
+        # type: () -> Graphics
+        raise NotImplementedError
