@@ -7,6 +7,8 @@ this package will cause a NullPointerException to be thrown.
 from __future__ import print_function
 
 __all__ = [
+    "BufferedReader",
+    "BufferedWriter",
     "Closeable",
     "DataOutputStream",
     "File",
@@ -14,6 +16,7 @@ __all__ = [
     "FileOutputStream",
     "FilterOutputStream",
     "Flushable",
+    "IOException",
     "InputStream",
     "OutputStream",
     "PrintStream",
@@ -22,9 +25,17 @@ __all__ = [
     "Writer",
 ]
 
-from typing import Any, Union
+from typing import Any, Optional, Union
 
-from java.lang import Appendable, AutoCloseable, CharSequence, Object, String
+from java.lang import (
+    Appendable,
+    AutoCloseable,
+    CharSequence,
+    Exception,
+    Object,
+    String,
+    Throwable,
+)
 
 
 class Closeable(AutoCloseable):
@@ -46,7 +57,7 @@ class File(Object):
     separatorChar = None  # type: String
 
     def __init__(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         pass
 
 
@@ -75,13 +86,13 @@ class OutputStream(Object, Closeable, Flushable):
         pass
 
     def write(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         pass
 
 
 class FileOutputStream(OutputStream):
     def __init__(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         pass
 
     def getChannel(self):
@@ -162,12 +173,12 @@ class PrintStream(FilterOutputStream):
     _out = OutputStream()
 
     def __init__(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         print(args)
         super(PrintStream, self).__init__(self._out)
 
     def append(self, *args):
-        # type: (Any) -> PrintStream
+        # type: (*Any) -> PrintStream
         pass
 
     def checkError(self):
@@ -175,7 +186,7 @@ class PrintStream(FilterOutputStream):
         pass
 
     def format(self, *args):
-        # type: (Any) -> PrintStream
+        # type: (*Any) -> PrintStream
         pass
 
     def print(self, arg):
@@ -183,7 +194,7 @@ class PrintStream(FilterOutputStream):
         pass
 
     def printf(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         pass
 
     def println(self, arg):
@@ -214,7 +225,7 @@ class InputStream(Object, Closeable):
         pass
 
     def read(self, *args):
-        # type: (Any) -> int
+        # type: (*Any) -> int
         pass
 
     def readAllBytes(self):
@@ -222,7 +233,7 @@ class InputStream(Object, Closeable):
         pass
 
     def readNBytes(self, *args):
-        # type: (Any) -> int
+        # type: (*Any) -> int
         pass
 
     def reset(self):
@@ -238,6 +249,12 @@ class InputStream(Object, Closeable):
         pass
 
 
+class IOException(Exception):
+    def __init__(self, message=None, cause=None):
+        # type: (Optional[str], Optional[Throwable]) -> None
+        super(IOException, self).__init__(message, cause)
+
+
 class Reader(Object, AutoCloseable):
     def close(self):
         # type: () -> None
@@ -257,7 +274,7 @@ class Reader(Object, AutoCloseable):
         pass
 
     def read(self, *args):
-        # type: (Any) -> int
+        # type: (*Any) -> int
         pass
 
     def ready(self):
@@ -277,6 +294,16 @@ class Reader(Object, AutoCloseable):
         pass
 
 
+class BufferedReader(Reader):
+    def __init__(self, in_, sz=None):
+        # type: (Reader, Optional[int]) -> None
+        print(in_, sz)
+
+    def close(self):
+        # type: () -> None
+        pass
+
+
 class Writer(Object, Appendable, Closeable, Flushable):
     def append(self, c_csq, start=0, end=-1):
         # type: (Union[CharSequence, str], int, int) -> Writer
@@ -296,13 +323,19 @@ class Writer(Object, Appendable, Closeable, Flushable):
         pass
 
     def write(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         pass
 
 
+class BufferedWriter(Writer):
+    def __init__(self, out, sz=None):
+        # type: (Writer, Optional[int]) -> None
+        print(out, sz)
+
+
 class PrintWriter(Writer):
     def __init__(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         pass
 
     def append(self, c_csq, start=0, end=-1):
@@ -314,7 +347,7 @@ class PrintWriter(Writer):
         pass
 
     def format(self, *args):
-        # type: (Any) -> PrintWriter
+        # type: (*Any) -> PrintWriter
         pass
 
     def print(self, arg):
@@ -322,7 +355,7 @@ class PrintWriter(Writer):
         pass
 
     def printf(self, *args):
-        # type: (Any) -> PrintWriter
+        # type: (*Any) -> PrintWriter
         pass
 
     def println(self, arg):
@@ -330,5 +363,5 @@ class PrintWriter(Writer):
         pass
 
     def write(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         pass
