@@ -1,6 +1,6 @@
 """Package information."""
 
-__version__ = "8.1.20"
-__build__ = "2022082313"
-__cycle__ = ".post4"
+__version__ = "8.1.21"
+__build__ = "2022092908"
+__cycle__ = ""
 __package_version__ = "{0}{1}".format(__version__, __cycle__)  # type: str
