@@ -7,6 +7,13 @@ interfaces.
 from __future__ import print_function
 
 __all__ = [
+    "ACCL_CONSTANT",
+    "ACCL_EASE",
+    "ACCL_FAST_TO_SLOW",
+    "ACCL_NONE",
+    "ACCL_SLOW_TO_FAST",
+    "COORD_DESIGNER",
+    "COORD_SCREEN",
     "chooseColor",
     "closeDesktop",
     "color",
@@ -48,6 +55,7 @@ from com.inductiveautomation.factorypmi.application.script.builtin import (
     WindowUtilities,
 )
 from java.awt import Color
+from java.lang import String
 from java.org.jdesktop.core.animation.timing import Animator
 from java.util import EventObject
 from javax.swing import (
@@ -60,8 +68,6 @@ from javax.swing import (
     JTextField,
 )
 
-String = Union[str, unicode]
-
 # Constants
 ACCL_NONE = 0
 ACCL_CONSTANT = 1
@@ -405,8 +411,8 @@ def getWindowNames():
     return "Main Window", "Main Window 1", "Main Window 2"
 
 
-def inputBox(message, defaultText=None):
-    # type: (String, Optional[String]) -> Optional[String]
+def inputBox(message, defaultText=""):
+    # type: (String, String) -> Optional[String]
     """Opens up a popup input dialog box.
 
     This dialog box will show a prompt message, and allow the user to
@@ -470,13 +476,13 @@ def messageBox(message, title="Information"):
 
 
 def openDesktop(
-    screen=0,  # type: Optional[int]
+    screen=0,  # type: int
     handle=None,  # type: Optional[String]
     title=None,  # type: Optional[String]
     width=None,  # type: Optional[int]
     height=None,  # type: Optional[int]
-    x=0,  # type: Optional[int]
-    y=0,  # type: Optional[int]
+    x=0,  # type: int
+    y=0,  # type: int
     windows=None,  # type: Optional[List[String]]
 ):
     # type: (...) -> JFrame
@@ -526,8 +532,8 @@ def openDiagnostics():
 
 def passwordBox(
     message,  # type:String
-    title="Password",  # type: Optional[String]
-    echoChar="*",  # type: Optional[String]
+    title="Password",  # type: String
+    echoChar="*",  # type: String
 ):
     # type: (...) -> Optional[String]
     """Pops up a special input box that uses a password field, so the
@@ -576,7 +582,7 @@ def setTouchscreenModeEnabled(enabled):
 def showNumericKeypad(
     initialValue,  # type: Union[float, int]
     fontSize=None,  # type: Optional[int]
-    usePasswordMode=False,  # type: Optional[bool]
+    usePasswordMode=False,  # type: bool
 ):
     # type: (...) -> Union[float, int]
     """Displays a modal on-screen numeric keypad, allowing for arbitrary
@@ -622,9 +628,9 @@ def transform(
     newY=None,  # type: Optional[int]
     newWidth=None,  # type: Optional[int]
     newHeight=None,  # type: Optional[int]
-    duration=0,  # type: Optional[int]
+    duration=0,  # type: int
     callback=None,  # type: Optional[Callable[..., Any]]
-    framesPerSecond=60,  # type: Optional[int]
+    framesPerSecond=60,  # type: int
     acceleration=None,  # type: Optional[int]
     coordSpace=None,  # type: Optional[int]
 ):
